Page Menu
Home
FreeBSD
Search
Configure Global Search
Log In
Files
F151615712
D50938.id157315.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Flag For Later
Award Token
Size
619 B
Referenced Files
None
Subscribers
None
D50938.id157315.diff
View Options
diff --git a/sys/kern/kern_mib.c b/sys/kern/kern_mib.c
--- a/sys/kern/kern_mib.c
+++ b/sys/kern/kern_mib.c
@@ -574,12 +574,11 @@
}
/*
* NOTICE: The *userland* release date is available in
* /usr/include/osreldate.h
*/
SYSCTL_PROC(_kern, KERN_OSRELDATE, osreldate,
CTLTYPE_INT | CTLFLAG_CAPRD | CTLFLAG_RD | CTLFLAG_MPSAFE,
- NULL, 0, sysctl_osreldate, "I", "Kernel release date");
+ NULL, 0, sysctl_osreldate, "I", "Kernel version");
/*
* The build-id is copied from the ELF section .note.gnu.build-id. The linker
File Metadata
@@ -574,12 +574,11 @@
}
/*
- * NOTICE: The *userland* release date is available in
- * /usr/include/osreldate.h
+ * NOTICE: The *userland* version is available in /usr/include/osreldate.h
*/
SYSCTL_PROC(_kern, KERN_OSRELDATE, osreldate,
Details
Attached
Mime Type
text/plain
Expires
Fri, Apr 10, 12:51 PM (20 h, 57 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
31186566
Default Alt Text
D50938.id157315.diff (619 B)
Attached To
Mode
D50938: sys: Correct kern.osreldate description
Attached
Detach File
Event Timeline
Log In to Comment